Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.emf.cdo.tests.hibernate/src/org/eclipse/emf/cdo/tests/hibernate/model/HibernateTest/Bz398057B.java')
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.hibernate/src/org/eclipse/emf/cdo/tests/hibernate/model/HibernateTest/Bz398057B.java22
1 files changed, 11 insertions, 11 deletions
diff --git a/plugins/org.eclipse.emf.cdo.tests.hibernate/src/org/eclipse/emf/cdo/tests/hibernate/model/HibernateTest/Bz398057B.java b/plugins/org.eclipse.emf.cdo.tests.hibernate/src/org/eclipse/emf/cdo/tests/hibernate/model/HibernateTest/Bz398057B.java
index d1b8006da5..448b1e29bd 100644
--- a/plugins/org.eclipse.emf.cdo.tests.hibernate/src/org/eclipse/emf/cdo/tests/hibernate/model/HibernateTest/Bz398057B.java
+++ b/plugins/org.eclipse.emf.cdo.tests.hibernate/src/org/eclipse/emf/cdo/tests/hibernate/model/HibernateTest/Bz398057B.java
@@ -14,7 +14,7 @@ import org.eclipse.emf.ecore.EObject;
* <ul>
* <li>{@link org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.Bz398057B#getRefToClassA <em>Ref To Class A</em>}</li>
* <li>{@link org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.Bz398057B#getValue <em>Value</em>}</li>
- * <li>{@link org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.Bz398057B#getId <em>Id</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.Bz398057B#getDbId <em>Db Id</em>}</li>
* </ul>
* </p>
*
@@ -78,30 +78,30 @@ public interface Bz398057B extends EObject {
void setValue(double value);
/**
- * Returns the value of the '<em><b>Id</b></em>' attribute.
+ * Returns the value of the '<em><b>Db Id</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Id</em>' attribute isn't clear,
+ * If the meaning of the '<em>Db Id</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Id</em>' attribute.
* @see #setId(String)
* @see org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.HibernateTestPackage#getBz398057B_Id()
* @model required="true"
* annotation="teneo.jpa value='@Id'"
* @generated
*/
- String getId();
+ String getDbId();
/**
* Sets the value of the '{@link org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.Bz398057B#getId <em>Id</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Id</em>' attribute.
* @see #getId()
* @generated
*/
- void setId(String value);
+ void setDbId(String value);
} // Bz398057B

Back to the top
@@ -78,30 +78,30 @@ public interface Bz398057B extends EObject {
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Id</em>' attribute.
- * @see #setId(String)
- * @see org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.HibernateTestPackage#getBz398057B_Id()
+ * @return the value of the '<em>Db Id</em>' attribute.
+ * @see #setDbId(String)
+ * @see org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.HibernateTestPackage#getBz398057B_DbId()
* @model required="true"
* annotation="teneo.jpa value='@Id'"
@@ -78,30 +78,30 @@ public interface Bz398057B extends EObject {
/**
- * Sets the value of the '{@link org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.Bz398057B#getId <em>Id</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.emf.cdo.tests.hibernate.model.HibernateTest.Bz398057B#getDbId <em>Db Id</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -78,30 +78,30 @@ public interface Bz398057B extends EObject {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Id</em>' attribute.
- * @see #getId()
+ * @param value the new value of the '<em>Db Id</em>' attribute.
+ * @see #getDbId()
* @generated
*/